@@ -1,6 +1,6 @@
 import os
 
-PYTHONS = ["3.8", "3.7", "3.6", "3.5"]
+PYTHONS = ["3.8", "3.7", "3.6"]
 
 for python in PYTHONS:
     print("conda build -c conda-forge -c NostrumBioDiscovery conda_recipe/ --python={}".format(python))
